ifolder/www-apps/ifolder3-enterprise/files/3.9.1/gentoo-apache-path.patch

213 lines
11 KiB
Diff

diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/CertUpdate.cs ifolder3-enterprise-3.9.1.7638/src/server/setup/CertUpdate.cs
--- ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/CertUpdate.cs 2013-04-19 19:23:31.097433272 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/server/setup/CertUpdate.cs 2013-04-19 19:33:16.333116819 +0200
@@ -62,7 +62,7 @@
/// </summary>
class CertUpdate
{
- private const string apacheSimiasConf = "/etc/apache2/conf.d/simias.conf";
+ private const string apacheSimiasConf = "/etc/apache2/modules.d/90_simias.conf";
private const string SearchStr = "MonoSetEnv simias10 \"SimiasRunAsServer=true;SimiasDataDir=";
private const string datapathEnvStr = "SimiasDataDir=";
private const string certMgrCmd= "certmgr";
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/ifolder_cluster_setup ifolder3-enterprise-3.9.1.7638/src/server/setup/ifolder_cluster_setup
--- ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/ifolder_cluster_setup 2013-04-19 19:23:31.097433272 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/server/setup/ifolder_cluster_setup 2013-04-19 19:33:02.054295329 +0200
@@ -36,7 +36,7 @@
#*
#*******************************************************************************/
-CONF_FILE_PATH=/etc/apache2/conf.d
+CONF_FILE_PATH=/etc/apache2/modules.d
IFOLDER32BIT="/opt/novell/ifolder3/lib/simias"
IFOLDER64BIT="/opt/novell/ifolder3/lib64/simias"
OS_ARCH=`uname -m | grep -c x86_64`
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/ifolder_mono_setup.in ifolder3-enterprise-3.9.1.7638/src/server/setup/ifolder_mono_setup.in
--- ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/ifolder_mono_setup.in 2013-04-19 19:23:31.096433285 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/server/setup/ifolder_mono_setup.in 2013-04-19 19:34:30.654187678 +0200
@@ -37,7 +37,7 @@
#*******************************************************************************/
iFPrefix=@_bindir_@/../
-CONF_FILE_PATH=/etc/apache2/conf.d
+CONF_FILE_PATH=/etc/apache2/modules.d
MOD_MONO_CONF_PATH="/etc/apache2/mod_mono.conf"
MOD_MONO_CONF_FILE_PATH="/etc/apache2/conf.d/mod_mono.conf"
IFOLDER32BIT="/opt/novell/ifolder3/lib/simias"
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolder_proxy_rights_assign.in ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolder_proxy_rights_assign.in
--- ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolder_proxy_rights_assign.in 2013-04-19 19:23:31.096433285 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolder_proxy_rights_assign.in 2013-04-19 19:30:13.926397217 +0200
@@ -83,7 +83,7 @@
fi
# get the value of datapath
-datapath=`grep SimiasDataDir /etc/apache2/conf.d/simias.conf | gawk 'BEGIN { RS=";|\"" } { if (/^SimiasDataDir/) print gensub(/SimiasDataDir=/, "", 1) }'`
+datapath=`grep SimiasDataDir /etc/apache2/modules.d/90_simias.conf | gawk 'BEGIN { RS=";|\"" } { if (/^SimiasDataDir/) print gensub(/SimiasDataDir=/, "", 1) }'`
touch $datapath/proxydetails
echo "proxy_rights_assign">>$datapath/proxydetails
echo "$1">>$datapath/proxydetails
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolder_retrieve_proxy_creds.in ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolder_retrieve_proxy_creds.in
--- ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolder_retrieve_proxy_creds.in 2013-04-19 19:23:31.096433285 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolder_retrieve_proxy_creds.in 2013-04-19 19:26:55.184881828 +0200
@@ -40,7 +40,7 @@
MONO_CMD=""
function getProxy(){
- datapath=`grep SimiasDataDir /etc/apache2/conf.d/simias.conf | gawk 'BEGIN { RS=";|\"" } { if (/^SimiasDataDir/) print gensub(/SimiasDataDir=/, "", 1) }'`
+ datapath=`grep SimiasDataDir /etc/apache2/modules.d/90_simias.conf | gawk 'BEGIN { RS=";|\"" } { if (/^SimiasDataDir/) print gensub(/SimiasDataDir=/, "", 1) }'`
if [ $1 = "username" ]; then
$MONO_CMD iFolderProxySetup.exe $datapath retrieve_proxy_creds username $2 $3
exit $?
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolder_update_proxy_cred_store.in ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolder_update_proxy_cred_store.in
--- ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolder_update_proxy_cred_store.in 2013-04-19 19:23:31.096433285 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolder_update_proxy_cred_store.in 2013-04-19 19:26:39.355079728 +0200
@@ -82,7 +82,7 @@
fi
# get the value of datapath
-datapath=`grep SimiasDataDir /etc/apache2/conf.d/simias.conf | gawk 'BEGIN { RS=";|\"" } { if (/^SimiasDataDir/) print gensub(/SimiasDataDir=/, "", 1) }'`
+datapath=`grep SimiasDataDir /etc/apache2/modules.d/90_simias.conf | gawk 'BEGIN { RS=";|\"" } { if (/^SimiasDataDir/) print gensub(/SimiasDataDir=/, "", 1) }'`
touch $datapath/proxydetails
echo update_proxy_cred_store>>$datapath/proxydetails
echo "$1">>$datapath/proxydetails
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/webservices/iFolderServer.cs ifolder3-enterprise-3.9.1.7638/src/webservices/iFolderServer.cs
--- ifolder3-enterprise-3.9.1.7638.orig/src/webservices/iFolderServer.cs 2013-04-19 19:23:31.102433210 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/webservices/iFolderServer.cs 2013-04-19 19:34:14.288392279 +0200
@@ -1221,7 +1221,7 @@
try
{
- string path = Path.GetFullPath("/etc/apache2/conf.d/simias.conf");
+ string path = Path.GetFullPath("/etc/apache2/modules.d/90_simias.conf");
TextReader reader = (TextReader)File.OpenText(path);
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolderAdminSetup.cs ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolderAdminSetup.cs
--- ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolderAdminSetup.cs 2013-04-19 19:23:31.096433285 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolderAdminSetup.cs 2013-04-19 19:29:48.319717345 +0200
@@ -362,11 +362,11 @@
}
/// <summary>
/// Read the /etc/apache2/conf.d/simias.conf File and return data path.
/// </summary>
string ReadModMonoConfiguration()
{
- string path = Path.GetFullPath( "/etc/apache2/conf.d/simias.conf" );
+ string path = Path.GetFullPath( "/etc/apache2/modules.d/90_simias.conf" );
string dataPath = null;
if ( path == null || File.Exists( path ) == false )
return null;
@@ -397,11 +397,11 @@
}
/// <summary>
/// Setup the /etc/apache2/conf.d/ifolder_web.conf File
/// </summary>
void SetupModMono()
{
- string path = "/etc/apache2/conf.d/ifolder_admin.conf";
+ string path = "/etc/apache2/modules.d/90_ifolder_admin.conf";
string datapath = ReadModMonoConfiguration();
@@ -436,7 +436,7 @@
sslPrefix = "#";
}
if( iFolderMonoPath != null )
- writer.WriteLine( "Include {0}{1}", iFolderMonoPath, "/etc/apache2/conf.d//mod_mono.conf" );
+ writer.WriteLine( "Include {0}{1}", iFolderMonoPath, "/etc/apache2/modules.d/70_mod_mono.conf" );
else
{
string mod_mono2_path = "/etc/apache2/modules.d/70_mod_mono.conf";
@@ -362,11 +362,11 @@
}
/// <summary>
- /// Read the /etc/apache2/conf.d/simias.conf File and return data path.
+ /// Read the /etc/apache2/modules.d/90_simias.conf File and return data path.
/// </summary>
string ReadModMonoConfiguration()
@@ -397,11 +397,11 @@
}
/// <summary>
- /// Setup the /etc/apache2/conf.d/ifolder_web.conf File
+ /// Setup the /etc/apache2/modules.d/90_ifolder_web.conf File
/// </summary>
void SetupModMono()
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolderWebSetup.cs ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolderWebSetup.cs
--- ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/iFolderWebSetup.cs 2013-04-19 19:23:31.097433272 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/server/setup/iFolderWebSetup.cs 2013-04-19 19:32:49.914447098 +0200
@@ -404,11 +404,11 @@
}
/// <summary>
/// Read the /etc/apache2/conf.d/simias.conf File and return data path.
/// </summary>
string ReadModMonoConfiguration()
{
- string path = Path.GetFullPath( "/etc/apache2/conf.d/simias.conf" );
+ string path = Path.GetFullPath( "/etc/apache2/modules.d/90_simias.conf" );
string dataPath = null;
if ( path == null || File.Exists( path ) == false )
return null;
@@ -440,11 +440,11 @@
/// <summary>
/// Setup the /etc/apache2/conf.d/ifolder_web.conf File
/// </summary>
void SetupModMono()
{
- string path = "/etc/apache2/conf.d/ifolder_web.conf";
+ string path = "/etc/apache2/modules.d/90_ifolder_web.conf";
string datapath = ReadModMonoConfiguration();
@@ -404,11 +404,11 @@
}
/// <summary>
- /// Read the /etc/apache2/conf.d/simias.conf File and return data path.
+ /// Read the /etc/apache2/modules.d/90_simias.conf File and return data path.
/// </summary>
string ReadModMonoConfiguration()
@@ -440,11 +440,11 @@
/// <summary>
- /// Setup the /etc/apache2/conf.d/ifolder_web.conf File
+ /// Setup the /etc/apache2/modules.d/90_ifolder_web.conf File
/// </summary>
void SetupModMono()
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/SimiasServerSetup.cs ifolder3-enterprise-3.9.1.7638/src/server/setup/SimiasServerSetup.cs
--- ifolder3-enterprise-3.9.1.7638.orig/src/server/setup/SimiasServerSetup.cs 2013-04-19 19:23:31.096433285 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/server/setup/SimiasServerSetup.cs 2013-04-19 19:31:46.245243073 +0200
@@ -2437,11 +2437,11 @@
}
/// <summary>
/// Setup the /etc/apache2/conf.d/simias.conf File
/// </summary>
void SetupModMono()
{
- string path = Path.GetFullPath( "/etc/apache2/conf.d/simias.conf" );
+ string path = Path.GetFullPath( "/etc/apache2/modules.d/90_simias.conf" );
Console.WriteLine("Configuring {0}...", path);
string ModMonoServer2 = Environment.GetEnvironmentVariable("IFOLDER_MOD_MONO_SERVER2_PATH");
string iFolderMonoPath = Environment.GetEnvironmentVariable("IFOLDER_MONO_PATH");
@@ -2452,7 +2452,7 @@
using( StreamWriter writer = File.CreateText( path ) )
{
/* example
- Include /etc/apache2/conf.d/mod_mono.conf
+ Include /etc/apache2/modules.d/70_mod_mono.conf
Alias /simias10 "/usr/web"
AddMonoApplications simias10 "/simias10:/usr/web"
@@ -2513,11 +2513,11 @@
}
/// <summary>
/// Read the /etc/apache2/conf.d/simias.conf File and return data path.
/// </summary>
string ReadModMonoConfiguration()
{
- string path = Path.GetFullPath( "/etc/apache2/conf.d/simias.conf" );
+ string path = Path.GetFullPath( "/etc/apache2/modules.d/90_simias.conf" );
string dataPath = null;
if ( path == null || File.Exists( path ) == false )
return null;
@@ -2437,11 +2437,11 @@
}
/// <summary>
- /// Setup the /etc/apache2/conf.d/simias.conf File
+ /// Setup the /etc/apache2/modules.d/90_simias.conf File
/// </summary>
void SetupModMono()
@@ -2513,11 +2513,11 @@
}
/// <summary>
- /// Read the /etc/apache2/conf.d/simias.conf File and return data path.
+ /// Read the /etc/apache2/modules.d/90_simias.conf File and return data path.
/// </summary>
string ReadModMonoConfiguration()
diff -uNr ifolder3-enterprise-3.9.1.7638.orig/src/utils/restore/iFolderServer.cs ifolder3-enterprise-3.9.1.7638/src/utils/restore/iFolderServer.cs
--- ifolder3-enterprise-3.9.1.7638.orig/src/utils/restore/iFolderServer.cs 2013-04-19 19:23:31.126432910 +0200
+++ ifolder3-enterprise-3.9.1.7638/src/utils/restore/iFolderServer.cs 2013-04-19 19:33:42.493789766 +0200
@@ -3351,11 +3351,11 @@
}
/// <summary>
/// Read the /etc/apache2/conf.d/simias.conf File and return data path.
/// </summary>
public static string ReadModMonoConfiguration()
{
- string path = Path.GetFullPath( "/etc/apache2/conf.d/simias.conf" );
+ string path = Path.GetFullPath( "/etc/apache2/modules.d/90_simias.conf" );
string dataPath = null;
if ( path == null || File.Exists( path ) == false )
return null;
@@ -3351,11 +3351,11 @@
}
/// <summary>
- /// Read the /etc/apache2/conf.d/simias.conf File and return data path.
+ /// Read the /etc/apache2/modules.d/90_simias.conf File and return data path.
/// </summary>
public static string ReadModMonoConfiguration()